==> rivendell-3.4.0.tar.gz: rivendell-3.4.0/rdcastmanager/rdcastmanager_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Upravit podcast</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>Adresa el. pošty autora:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Skupina:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Adresa (URL) odkazu:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Zdrojový text:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>Adresa (URL) zdroje:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Adresa (URL) poznámky:</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Vyvěšeno:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Přestane platit:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="obsolete">Läuft ab am/um:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Držet</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Činný</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Stav vyvěšení:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>&amp;Zpráva o
dílu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation>Datum/Čas poslání:</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation>Multimediální odkaz:</translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation>Přestane platit:</translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation>Seznam podcastů</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Vyvěsit z
vozí&amp;ku/záběru</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Vyvěsit ze
&amp;souboru</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>Zpráva o
&amp;odběru</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source></source>
        <translation>Project-Id-Version: amarok
Report-Msgid-Bugs-To: http://bugs.kde.org
POT-Creation-Date: 2010-05-20 04:55+0200
PO-Revision-Date: 2010-05-22 09:34+0200
Last-Translator: Pavel Fric
Language-Team: Czech &lt;kde-i18n-doc@kde.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Generator: Lokalize 1.0
Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n&gt;=2 &amp;&amp; n&lt;=4) ? 1 : 2;
</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Původ</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Přestane platit</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Nahrává se zvuk...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Postup</translation>
    </message>
    <message>
        <source>Format Error</source>
        <translation type="obsolete">Formatfehler</translation>
    </message>
    <message>
        <source>Unable to convert audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht konvertieren!</translation>
    </message>
    <message>
        <source>Upload Error</source>
        <translation type="obsolete">Fehler beim Hochladen</translation>
    </message>
    <message>
        <source>Unable to upload audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht hochladen!</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation>Smazat podcast</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation>Opravdu chcete smazat tento podcast?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation>Maže se podcast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="obsolete">Kann den Löschbefehl nicht generieren!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Chyba u protistrany</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="obsolete">Kann das entfernte Audio nicht Löschen!
Podcast trotzdem löschen?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Dateifehler</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation type="obsolete">Datei existiert nicht!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Kann die Datei nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Nicht unterstützter Dateityp!</translation>
    </message>
    <message>
        <source> </source>
        <translation> </translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation>Ukázat jen podcasty, co platí</translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation>Ukázat jen činné podcasty</translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation>Chyba při vyvěšení</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation>Nelze smazat soubory se zvukem na jiném serveru!</translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation>Server hlásí: &quot;</translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation>Pokračovat v mazání podcastu?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="obsolete">RDCastManager - Server</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Uživatel: [Neznámý]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Nelze spojit</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Název klíče</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Název přívodu</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Podcasty</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Zobrazit
přívod</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished">&amp;Vybrat</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-3.6.1.tar.gz: rivendell-3.6.1/rdcastmanager/rdcastmanager_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation type="obsolete">Upravit podcast</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>Adresa el. pošty autora:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Skupina:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Adresa (URL) odkazu:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation type="obsolete">Zdrojový text:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation type="obsolete">Adresa (URL) zdroje:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Adresa (URL) poznámky:</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation type="obsolete">Vyvěšeno:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation type="obsolete">Přestane platit:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="obsolete">Läuft ab am/um:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="obsolete">&amp;Vybrat</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation type="obsolete">Držet</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Činný</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation type="obsolete">Stav vyvěšení:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation type="obsolete">&amp;Zpráva o
dílu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation>Datum/Čas poslání:</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation type="obsolete">Multimediální odkaz:</translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation type="obsolete">Přestane platit:</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item contains explicit content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Editing Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posted By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item expiration cannot be prior to Air Date/Time!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item expiration must be in the future!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation type="obsolete">Seznam podcastů</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Vyvěsit z
vozí&amp;ku/záběru</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Vyvěsit ze
&amp;souboru</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation type="obsolete">Zpráva o
&amp;odběru</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source></source>
        <translation>Project-Id-Version: amarok
Report-Msgid-Bugs-To: http://bugs.kde.org
POT-Creation-Date: 2010-05-20 04:55+0200
PO-Revision-Date: 2010-05-22 09:34+0200
Last-Translator: Pavel Fric
Language-Team: Czech &lt;kde-i18n-doc@kde.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Generator: Lokalize 1.0
Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n&gt;=2 &amp;&amp; n&lt;=4) ? 1 : 2;
</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="obsolete">Původ</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation type="obsolete">Přestane platit</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Popis</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Odkaz</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Nahrává se zvuk...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Postup</translation>
    </message>
    <message>
        <source>Format Error</source>
        <translation type="obsolete">Formatfehler</translation>
    </message>
    <message>
        <source>Unable to convert audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht konvertieren!</translation>
    </message>
    <message>
        <source>Upload Error</source>
        <translation type="obsolete">Fehler beim Hochladen</translation>
    </message>
    <message>
        <source>Unable to upload audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht hochladen!</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation type="obsolete">Smazat podcast</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation type="obsolete">Opravdu chcete smazat tento podcast?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation type="obsolete">Maže se podcast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="obsolete">Kann den Löschbefehl nicht generieren!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Chyba u protistrany</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="obsolete">Kann das entfernte Audio nicht Löschen!
Podcast trotzdem löschen?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Dateifehler</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation type="obsolete">Datei existiert nicht!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Kann die Datei nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Nicht unterstützter Dateityp!</translation>
    </message>
    <message>
        <source> </source>
        <translation> </translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation type="obsolete">Ukázat jen podcasty, co platí</translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation type="obsolete">Ukázat jen činné podcasty</translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation>Chyba při vyvěšení</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation type="obsolete">Nelze smazat soubory se zvukem na jiném serveru!</translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation>Server hlásí: &quot;</translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation>Pokračovat v mazání podcastu?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcast Item List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Active Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posted By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expiration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this item?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting Item...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Audio File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to drop remote audio!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to update remote XML data!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogDialog</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At least one log event must be selected!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List Log Events</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogModel</name>
    <message>
        <source>Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Název</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Délka</translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ext Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="obsolete">RDCastManager - Server</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Uživatel: [Neznámý]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Nelze spojit</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Název klíče</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Název přívodu</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Popis</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Podcasty</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Zobrazit
přívod</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy URL to
Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[superfeed]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>&amp;Select</source>
        <translation type="obsolete">&amp;Vybrat</translation>
    </message>
</context>
<context>
    <name>RenderDialog</name>
    <message>
        <source>[now]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As Specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Treat as PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At STOP transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Log Render Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected Log Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>through</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
